@@ -33,7 +33,7 @@ def check_diff_responses():
                 click.secho(f"  {'Difference'}              | {result}")
                 message = f"ERROR {result}"
                 play.Replayed.errors.append(AssertionError(message))
-    if not play.Replayed.errors:
+    if play.Replayed.errors:
         raise AssertionError
                 #exception_cls = get_grouped_exception(*play.Replayed.errors)
                 #raise exception_cls(play.Replayed.errors)
